﻿/**
 * This class uses the Silex API in order to register animations for the layout
 * @author lex@silex.tv
 */

package ;
import flash.Lib;
import flash.MovieClip;

class LayoutHandler 
{
	///////////////////////////////////////////////////////////
	// Group: constants
	///////////////////////////////////////////////////////////
	/**
	 * name of the unique layer of the minimal layout
	 */
	static inline var LAYER_NAME:String = "HAXE LAYER";
	/**
	 * speed of the fade in and out, between 1 and 100
	 */
	static inline var FADE_SPEED:Int = 1;
	///////////////////////////////////////////////////////////
	// Group: visual elements
	///////////////////////////////////////////////////////////
	/**
	 * the main timeline of the laout, passed in the constructor by the class Main
	 */
	private var timeline:MovieClip;
	/**
	 * container for the unique layer of the minimal layout
	 */
	public var layerContainer:MovieClip;
	/**
	 * object which handle the anim
	 */
	public var showAnim:LayoutAnim;
	/**
	 * object which handle the anim
	 */
	public var hideAnim:LayoutAnim;
	///////////////////////////////////////////////////////////
	// Group: Silex API objects
	///////////////////////////////////////////////////////////
	/**
	 * reference to SIlex API
	 */
	private var silex_ptr:Dynamic;
	/**
	 * reference to Silex Layout class for this layout
	 */
	private var layout:Dynamic;
	///////////////////////////////////////////////////////////
	// Group: methods
	///////////////////////////////////////////////////////////
	/**
	 * constructor
	 */
	public function new() 
	{
		// local root timeline
		timeline = Lib.current;
		silex_ptr = Lib._global.getSilex();
		layout = silex_ptr.application.getLayout(timeline);


		// create container for layer
		layerContainer = timeline.createEmptyMovieClip("layerContainer", timeline.getNextHighestDepth());
		layerContainer._alpha = 0;
		
		// create animation clips
		showAnim = new LayoutAnim(fadeIn);
		hideAnim = new LayoutAnim(fadeOut);
		
		// register anims
		// flash.Lib._global.getSilex(). .. registerAnim(showAnim,showAnimPlay);
		layout.registerAnim(showAnim,silex_ptr.config.ANIM_NAME_SHOW, false);
		layout.registerAnim(hideAnim,silex_ptr.config.ANIM_NAME_CLOSE, false);
		
		// register layers in next frame
		silex_ptr.sequencer.doInNextFrame(onLoad);
	}
	/**
	 * init function after first frame has executed
	 */
	private function onLoad()
	{
		trace("onLoad "+layout);
		if (layout)
		{
			// register layout
			layout.registerLayoutContainer(timeline);
			// register layers
			layout.registerLayerContainer(layerContainer, LAYER_NAME);
		}
	}
	/**
	 * fade function
	 */
	public function fadeIn()
	{
		trace("fadeIn");
		layerContainer._alpha += FADE_SPEED;
		layerContainer._x += (.5-Math.random())*10;
		if(layerContainer._alpha<100)
			timeline.onEnterFrame = fadeIn;
		else
			timeline.onEnterFrame = null;
	}
	/**
	 * fade function
	 */
	public function fadeOut()
	{
		trace("fadeOut");
		layerContainer._alpha-=FADE_SPEED;
		if(layerContainer._alpha<=0)
			timeline.onEnterFrame = fadeOut;
		else
			timeline.onEnterFrame = null;
	}
}